@@ -1,36 +1,54 @@
 # dio.tcl -- implements a database abstraction layer.
 
 # Copyright 2002-2004 The Apache Software Foundation
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #       http://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id$
-
 catch {package require Tclx}
 package require Itcl
+package require dio::formatters
+
 ##set auto_path [linsert $auto_path 0 [file dirname [info script]]]
 
 namespace eval ::DIO {
 
 proc handle {interface args} {
-    set obj \#auto
+    set obj ::DIO::#auto
+    set tdbc_driver ""
+    if {($interface == "Tdbc") && ([llength $args] > 0)} {
+        set tdbc_driver [lindex $args 0]
+        set args [lreplace $args 0 0]
+    }
+
+    #puts "interface: $interface ($tdbc_driver)"
+
     set first [lindex $args 0]
     if {![::rivet::lempty $first] && [string index $first 0] != "-"} {
         set obj  [lindex $args 0]
         set args [lreplace $args 0 0]
     }
     uplevel \#0 package require dio_$interface
-    return [uplevel \#0 ::DIO::$interface $obj $args]
+
+    #puts "tdbc: '$tdbc_driver' obj: '$obj' args 3: '$args'"
+
+    if {$tdbc_driver == ""} {
+
+        # old connectors based on traditional dbms drivers
+
+        return [uplevel \#0 ::DIO::$interface $obj $args]
+    } else {
+        return [uplevel \#0 ::DIO::$interface $obj $tdbc_driver {*}$args]
+    }
 }
 
 ##
@@ -39,6 +57,7 @@ proc handle {interface args} {
 ::itcl::class Database {
     constructor {args} {
         eval configure $args
+        set special_fields_formatter [::DIO::formatters::${interface} ::DIO::formatters::#auto]
     }
 
     destructor {
@@ -58,9 +77,8 @@ proc handle {interface args} {
     # quote - given a string, return the same string with any single
     #  quote characters preceded by a backslash
     #
-    method quote {string} {
-        regsub -all {'} $string {\'} string
-        return $string
+    method quote {a_string} {
+        return [DIO::formatters::quote $a_string]
     }
 
     #
@@ -72,11 +90,11 @@ proc handle {interface args} {
     #
     protected method build_select_query {args} {
 
-        set bool AND
-        set first 1
-        set req ""
+        set bool    AND
+        set first   1
+        set req     ""
         set myTable $table
-        set what "*"
+        set what    "*"
 
         # for each argument passed us...
         # (we go by integers because we mess with the index based on
@@ -600,12 +618,27 @@ proc handle {interface args} {
         return [string "select count(*) from $myTable"]
     }
 
-    method makeDBFieldValue {table_name field_name val} {
-        return "'[quote $val]'"
+    protected method set_field_formatter {formatter_class} {
+        $special_fields_formatter destroy
+        set special_fields_formatter [$formatter_class ::DIO::formatters::#auto]
     }
 
-    method registerSpecialField {table_name field_name type} {
-        set specialFields(${table_name}@${field_name}) $type
+    public method build_special_field {table_name field_name val {convert_to {}}} {
+        return [$special_fields_formatter build $table_name $field_name $val $convert_to]
+    }
+
+    public method register_special_field {table_name field_name type} {
+        $special_fields_formatter register $table_name $field_name $type
+    }
+
+    # method kept for compatibility
+
+    public method registerSpecialField {table_name field_name type} {
+        $this register_special_field $table_name $field_name $type
+    }
+
+    public method makeDBFieldValue {table_name field_name val {convert_to {}}} {
+        return [$this build_special_field $table_name $field_name $val]
     }
 
     ##
@@ -617,8 +650,8 @@ proc handle {interface args} {
     method exec    {args} {}
     method nextkey {args} {}
     method lastkey {args} {}
-    method now {} {}
-
+    method now     {}     {}
+    method last_inserted_rec {} {}
     ##
     ## Functions to get and set public variables.
     ##
@@ -634,7 +667,8 @@ proc handle {interface args} {
     method host {{string ""}} { return [configure_variable host $string] }
     method port {{string ""}} { return [configure_variable port $string] }
 
-    protected variable specialFields
+    public variable special_fields_formatter \
+                    [::DIO::formatters::RootFormatter ::DIO::formatters::#auto]
 
     public variable interface   ""
     public variable errorinfo   ""
@@ -648,6 +682,12 @@ proc handle {interface args} {
     public variable host        ""
     public variable port        ""
 
+    protected method handle_client_arguments {cargs} { }
+
+    public variable clientargs  "" {
+        handle_client_arguments $clientargs
+    }
+
     public variable keyfield    "" {
         if {[llength $keyfield] > 1 && $autokey} {
             return -code error "Cannot have autokey and multiple keyfields"
@@ -868,4 +908,4 @@ proc handle {interface args} {
 
 } ; ## namespace eval DIO
 
-package provide DIO 1.1
+package provide DIO 1.2
