@@ -17,14 +17,14 @@
 #    specific language governing permissions and limitations
 #    under the License.
 
-package require DIO
-package provide dio_Mysql 0.4
+package require DIO       1.2
+package provide dio_Mysql 1.2
 
 namespace eval DIO {
     ::itcl::class Mysql {
         inherit Database
 
-        constructor {args} {eval configure $args} {
+        constructor {args} {eval configure -interface Mysql $args} {
             if {   [catch {package require Mysqltcl}]   \
                 && [catch {package require mysqltcl}]   \
                 && [catch {package require mysql}]} {
@@ -39,6 +39,7 @@ namespace eval DIO {
                 }
                 set db $user
             }
+
         }
 
         destructor {
@@ -96,9 +97,9 @@ namespace eval DIO {
                 return $obj
             }
             if {[catch {mysqlcol $conn -current name} fields]} { set fields "" }
-            set obj [result Mysql   -resultid   $conn               \
-                                    -numrows    [::list $error]     \
-                                    -fields     [::list $fields]]
+            set obj [result Mysql -resultid   $conn               \
+                                  -numrows    [::list $error]     \
+                                  -fields     [::list $fields]]
             return $obj
         }
 
@@ -125,87 +126,13 @@ namespace eval DIO {
             return $conn
         }
 
-        method makeDBFieldValue {table_name field_name val {convert_to {}}} {
-
-            if {[info exists specialFields(${table_name}@${field_name})]} {
-                switch $specialFields(${table_name}@${field_name}) {
-
-                    DATE {
-                        set secs [clock scan $val]
-                        set my_val [clock format $secs -format {%Y-%m-%d}]
-                        return "DATE_FORMAT('$my_val','%Y-%m-%d')"
-                    }
-                    DATETIME {
-                        set secs [clock scan $val]
-                        set my_val [clock format $secs -format {%Y-%m-%d %T}]
-                        return "DATE_FORMAT('$my_val','%Y-%m-%d %T')"
-                    }
-                    NOW {
-
-		    # we try to be coherent with the original purpose of this method whose
-		    # goal is endow the class with a uniform way to handle timestamps. 
-		    # E.g.: Package session expects this case to return a timestamp in seconds
-		    # so that differences with timestamps returned by [clock seconds]
-		    # can be done and session expirations are computed consistently.
-		    # (Bug #53703)
-
-                        switch $convert_to {
-
-                            SECS {
-                                if {[::string compare $val "now"] == 0} {
-
-#                                   set     secs    [clock seconds]
-#                                   set     my_val  [clock format $secs -format {%Y%m%d%H%M%S}]
-#                                   return  $my_val
-
-                                    return [clock seconds]
-
-                                } else {
-                                    return  "UNIX_TIMESTAMP($field_name)"
-                                }
-                            }
-                            default {
-
-                                if {[::string compare $val, "now"] == 0} {
-                                    set secs [clock seconds]
-                                } else {
-                                    set secs [clock scan $val]
-                                }
-
-                                # this is kind of going back and forth from the same 
-                                # format,
-
-                                #set my_val [clock format $secs -format {%Y-%m-%d %T}]
-                                return "FROM_UNIXTIME('$secs')"
-                            }
-                        }
-                    }
-                    NULL {
-                        if {[::string toupper $val] == "NULL"} {
-                            return $val
-                        } else {
-                            return "'[quote $val]'"
-                        }
-                    }
-                    default {
-                        # no special code for that type!!
-                        return "'[quote $val]'"
-                    }
-                }
-
-            } else {
-                return "'[quote $val]'"
-            }
-
-        }
-
         public variable db "" {
             if {[info exists conn] && [mysqlping $conn]} {
                 mysqluse $conn $db
             }
         }
 
-        protected method handle_client_arguments {cargs} { 
+        protected method handle_client_arguments {cargs} {
 
             # we assign only the accepted options
 
@@ -228,7 +155,7 @@ namespace eval DIO {
             }
         }
 
-        public  variable interface "Mysql"
+        #public  variable interface "Mysql"
         private variable conn
 
     } ; ## ::itcl::class Mysql
