@@ -37,7 +37,7 @@ static void req_plustospace(char *str)
 }
 
 static int
-util_read(ApacheRequest *req, const char **rbuf)
+util_read(ApacheRequest *req, const char **rbuf, int *rlen)
 {
     request_rec *r = req->r;
     int rc = OK;
@@ -61,6 +61,7 @@ util_read(ApacheRequest *req, const char **rbuf)
         }
 
         *rbuf = apr_pcalloc(r->pool, length + 1);
+	*rlen = length;
 
         while ((len_read =
                     ap_get_client_block(r, buff, sizeof(buff))) > 0) {
@@ -215,6 +216,7 @@ ApacheRequest *ApacheRequest_new(apr_pool_t *pool)
     req->hook_data      = NULL;
     req->temp_dir       = NULL;
     req->raw_post       = NULL;
+    req->raw_length     = 0;
     req->parsed         = 0;
     req->r              = NULL;
     req->nargs          = 0;
@@ -234,6 +236,7 @@ ApacheRequest *ApacheRequest_init(ApacheRequest* req, request_rec *r)
     req->hook_data      = NULL;
     req->temp_dir       = NULL;
     req->raw_post       = NULL;
+    req->raw_length     = 0;
     req->parsed         = 0;
     req->r              = r;
     req->nargs          = 0;
@@ -409,7 +412,7 @@ int ApacheRequest___parse(ApacheRequest *req)
         req->nargs = ((apr_array_header_t *)req->parms)->nelts;
     }
 
-    if ((r->method_number == M_POST) && ct && strncaseEQ(ct, MULTIPART_ENCTYPE, MULTIPART_ENCTYPE_LENGTH)) 
+    if ((r->method_number == M_POST) && ct && strncaseEQ(ct, MULTIPART_ENCTYPE, MULTIPART_ENCTYPE_LENGTH))
     {
         //
         //ap_log_rerror(REQ_INFO, "content-type: `%s'", ct);
@@ -432,23 +435,25 @@ int ApacheRequest_parse_urlencoded(ApacheRequest *req)
 
     if (r->method_number == M_POST || r->method_number == M_PUT || r->method_number == M_DELETE) {
     	const char *data = NULL;
+	int length = 0;
 
     /*
         const char *type;
     	type = apr_table_get(r->headers_in, "Content-Type");
-    
+
     	if (!strncaseEQ(type, DEFAULT_ENCTYPE, DEFAULT_ENCTYPE_LENGTH) &&
     	    !strncaseEQ(type, TEXT_XML_ENCTYPE, TEXT_XML_ENCTYPE_LENGTH)) {
     	    return DECLINED;
     	}
     */
 
-    	if ((rc = util_read(req, &data)) != OK) {
+    	if ((rc = util_read(req, &data, &length)) != OK) {
     	    return rc;
     	}
 
     	if (data) {
     	    req->raw_post = (char*) data; /* Give people a way of getting at the raw data. */
+    	    req->raw_length = length;
     	    split_to_parms(req, data);
     	}
     }
@@ -482,14 +487,14 @@ apr_file_t *ApacheRequest_tmpfile(ApacheRequest *req, ApacheUpload *upload)
     request_rec *r = req->r;
     apr_file_t *fp = NULL;
     char *name = NULL;
-    char *file = NULL ; 
+    char *file = NULL ;
     const char *tempdir;
     apr_status_t rv;
 	
     tempdir = req->temp_dir;
 /*	file = (char *)apr_palloc(r->pool,sizeof(apr_time_t)); */
     file = apr_psprintf(r->pool,"%u.XXXXXX", (unsigned int)r->request_time);
-    rv = apr_temp_dir_get(&tempdir,r->pool); 
+    rv = apr_temp_dir_get(&tempdir,r->pool);
     if (rv != APR_SUCCESS)  {
 	ap_log_perror(APLOG_MARK, APLOG_ERR, rv, r->pool, "No temp dir!");
 	return NULL;
@@ -500,7 +505,7 @@ apr_file_t *ApacheRequest_tmpfile(ApacheRequest *req, ApacheUpload *upload)
 	ap_log_perror(APLOG_MARK, APLOG_ERR, rv, r->pool, "File path error!");
 	return NULL;
     }
-    
+
     rv = apr_file_mktemp(&fp,name,0,r->pool);
     if (rv != APR_SUCCESS) {
 	char* errorBuffer = (char*) apr_palloc(r->pool,256);
@@ -628,10 +633,10 @@ ApacheRequest_parse_multipart(ApacheRequest *req,const char* ct)
 
             /* mozilla empty-file (missing CRLF) hack */
             fill_buffer(mbuff);
-            if( strEQN(mbuff->buf_begin, mbuff->boundary, 
+            if( strEQN(mbuff->buf_begin, mbuff->boundary,
                         strlen(mbuff->boundary)) ) {
                 r->remaining -= 2;
-                continue; 
+                continue;
             }
 
             while ((blen = multipart_buffer_read(mbuff, buff, sizeof(buff)))) {
@@ -639,7 +644,7 @@ ApacheRequest_parse_multipart(ApacheRequest *req,const char* ct)
 				status = apr_file_write(upload->fp,buff,&bytes_to_write);
 				
 				if (status != 0) {
-					apr_strerror(status,error,1024); 
+					apr_strerror(status,error,1024);
                     return HTTP_INTERNAL_SERVER_ERROR;
 				}
                 upload->size += blen;
@@ -738,3 +743,9 @@ char *ApacheRequest_expires(ApacheRequest *req, char *time_str)
     return ApacheUtil_expires(req->r->pool, time_str, EXPIRES_HTTP);
 }
 
+char *ApacheRequest_get_raw_post(ApacheRequest *req, int *len)
+{
+    if (len)
+	*len = req->raw_length;
+    return req->raw_post;
+}
